@@ -1,9 +1,13 @@
 from ..permissions import IsUnauthenticated
-from .serializers import OTPObtainSerializer, InviteSerializer, ConnectSerializer
+from .serializers import ChangeSerializer
+from .serializers import ConnectSerializer
+from .serializers import InviteSerializer
+from .serializers import OTPObtainSerializer
 from .serializers import SignupSerializer
 from .serializers import SocialTokenObtainSerializer
 from .serializers import TokenObtainSerializer
 from .serializers import TokenSerializer
+from .serializers import UnlinkSerializer
 from django.conf import settings
 from rest_framework import permissions
 from rest_framework import response
@@ -26,20 +30,6 @@ class TokenViewSet(ValidationOnlyCreateViewSet):
     response_serializer_class = TokenSerializer
     permission_classes = (permissions.AllowAny,)
 
-    @action(methods=["post"], detail=False, serializer_class=SignupSerializer)
-    def signup(self, request, *args, **kwargs):
-        return self.create(request, *args, **kwargs)
-
-    @action(methods=["post"], detail=False, serializer_class=InviteSerializer,
-            permission_classes=(permissions.IsAuthenticated,))
-    def invite(self, request, *args, **kwargs):
-        return self.create(request, *args, **kwargs)
-
-    @action(methods=["post"], detail=False, serializer_class=ConnectSerializer,
-            permission_classes=(permissions.IsAuthenticated,))
-    def connect(self, request, *args, **kwargs):
-        return self.create(request, *args, **kwargs)
-
     @action(
         methods=["post"],
         detail=False,
@@ -68,6 +58,31 @@ class TokenViewSet(ValidationOnlyCreateViewSet):
         return self.create(request, *args, **kwargs)
 
 
+class SignupViewSet(ValidationOnlyCreateViewSet):
+    serializer_class = SignupSerializer
+    permission_classes = (permissions.AllowAny,)
+
+
+class ConnectViewSet(ValidationOnlyCreateViewSet):
+    serializer_class = ConnectSerializer
+    permission_classes = (permissions.IsAuthenticated,)
+
+
+class UnlinkViewSet(ValidationOnlyCreateViewSet):
+    serializer_class = UnlinkSerializer
+    permission_classes = (permissions.IsAuthenticated,)
+
+
+class ChangeViewSet(ValidationOnlyCreateViewSet):
+    serializer_class = ChangeSerializer
+    permission_classes = (permissions.IsAuthenticated,)
+
+
+class InviteViewSet(ValidationOnlyCreateViewSet):
+    serializer_class = InviteSerializer
+    permission_classes = (permissions.IsAuthenticated,)
+
+
 class OTPViewSet(ValidationOnlyCreateViewSet):
     throttle_scope = "otp"
     serializer_class = OTPObtainSerializer
